@@ -13,10 +13,24 @@ use warnings;
 use DateTime;
 use POSIX qw/ceil floor/;
 
-use Interchange6::Schema::Candy -components => [
+use Moo;
+
+extends 'DBIx::Class::Core';
+with('Interchange6::Schema::Role::Errors');
+
+use namespace::clean;
+
+# component load order is important so be careful here:
+__PACKAGE__->load_components(
     qw(InflateColumn::DateTime TimeStamp
       +Interchange6::Schema::Component::Validation)
-];
+);
+
+=head1 TABLE: C<taxes>
+
+=cut
+
+__PACKAGE__->table("taxes");
 
 =head1 DESCRIPTION
 
@@ -30,16 +44,6 @@ The taxes table contains taxes such as sales tax and VAT. Each tax has a unique
   is_auto_increment: 1
   is_nullable: 0
   sequence: 'taxes_id_seq'
-  primary key
-
-=cut
-
-primary_column taxes_id => {
-    data_type         => "integer",
-    is_auto_increment => 1,
-    is_nullable       => 0,
-    sequence          => "taxes_id_seq"
-};
 
 =head2 tax_name
 
@@ -47,43 +51,25 @@ primary_column taxes_id => {
   is_nullable: 0
   size: 64
 
-=cut
-
-column tax_name => { data_type => "varchar", is_nullable => 0, size => 64 };
-
 =head2 description
 
   data_type: 'varchar'
   is_nullable: 0
   size: 64
 
-=cut
-
-column description => { data_type => "varchar", is_nullable => 0, size => 64 };
-
 =head2 percent
 
   data_type: 'numeric'
   is_nullable: 0
   size: [7,4]
 
-=cut
-
-column percent =>
-  { data_type => "numeric", is_nullable => 0, size => [ 7, 4 ] };
-
-=head2 decimal_places
+=head2 precision
 
   data_type: 'integer'
   is_nullable: 0
   default_value: 2
 
-Number of decimal_places of precision required. Defaults to 2.
-
-=cut
-
-column decimal_places =>
-  { data_type => "integer", is_nullable => 0, default_value => 2 };
+Number of decimal places of precision required. Defaults to 2.
 
 =head2 rounding
 
@@ -92,12 +78,7 @@ column decimal_places =>
   size: 1
   default_value: undef
 
-Default rounding is half round up to the number of decimal_places. To use floor or ceiling set rounding to 'f' or 'c' as appropriate. The rounding value is automatically converted to lower case and any invalid value passed in will cause an exception to be thrown.
-
-=cut
-
-column rounding =>
-  { data_type => "char", is_nullable => 1, size => 1, default_value => undef };
+Default rounding is half round up to the precision number of decimal places. To use floor or ceiling set rounding to 'f' or 'c' as appropriate. The rounding value is automatically converted to lower case and any invalid value passed in will be ignored and instead undef will be stored giving default rounding.
 
 =head2 valid_from
 
@@ -105,31 +86,16 @@ column rounding =>
   set_on_create: 1
   is_nullable: 0
 
-=cut
-
-column valid_from =>
-  { data_type => "date", set_on_create => 1, is_nullable => 0 };
-
 =head2 valid_to
 
   data_type: 'date'
   is_nullable: 1
 
-=cut
-
-column valid_to => { data_type => "date", is_nullable => 1 };
-
 =head2 country_iso_code
 
   data_type: 'char'
   is_foreign_key: 1
   is_nullable: 1
-  size: 2
-
-=cut
-
-column country_iso_code =>
-  { data_type => "char", is_foreign_key => 1, is_nullable => 1, size => 2 };
 
 =head2 states_id
 
@@ -137,22 +103,12 @@ column country_iso_code =>
   is_foreign_key: 1
   is_nullable: 1
 
-=cut
-
-column states_id =>
-  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 };
-
 =head2 created
 
   data_type: 'datetime'
   set_on_create: 1
   is_nullable: 0
 
-=cut
-
-column created =>
-  { data_type => "datetime", set_on_create => 1, is_nullable => 0 };
-
 =head2 last_modified
 
   data_type: 'datetime'
@@ -162,53 +118,65 @@ column created =>
 
 =cut
 
-column last_modified => {
-    data_type     => "datetime",
-    set_on_create => 1,
-    set_on_update => 1,
-    is_nullable   => 0
+__PACKAGE__->add_columns(
+    "taxes_id",
+    {
+        data_type         => "integer",
+        is_auto_increment => 1,
+        is_nullable       => 0,
+        sequence          => "taxes_id_seq"
+    },
+    "tax_name",
+    { data_type => "varchar", is_nullable => 0, size => 64 },
+    "description",
+    { data_type => "varchar", is_nullable => 0, size => 64 },
+    "percent",
+    { data_type => "numeric", is_nullable => 0, size => [ 7, 4 ] },
+    "precision",
+    { data_type => "integer", is_nullable => 0, default_value => 2 },
+    "rounding",
+    {
+        data_type     => "char",
+        is_nullable   => 1,
+        size          => 1,
+        default_value => undef
+    },
+    "valid_from",
+    { data_type => "date", set_on_create => 1, is_nullable => 0 },
+    "valid_to",
+    { data_type => "date", is_nullable => 1 },
+    "country_iso_code",
+    { data_type => "char", is_foreign_key => 1, is_nullable => 1 },
+    "states_id",
+    { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
+    "created",
+    { data_type => "datetime", set_on_create => 1, is_nullable => 0 },
+    "last_modified",
+    {
+        data_type     => "datetime",
+        set_on_create => 1,
+        set_on_update => 1,
+        is_nullable   => 0
+    },
+);
+
+# for rounding to only store undef, c or f
+
+around rounding => sub {
+    my ( $orig, $self, @a ) = ( shift, shift, @_ );
+
+    if ( $a[0] ) {
+        if ( $a[0] =~ m/^(f|c)/i ) {
+            $a[0] = lc($1);
+        }
+        else {
+            $a[0] = undef;
+        }
+    }
+
+    $self->$orig(@a);
 };
 
-=head1 RELATIONS
-
-=head2 state
-
-Type: belongs_to
-
-Related object: L<Interchange6::Schema::Result::State>
-
-=cut
-
-belongs_to
-  state => "Interchange6::Schema::Result::State",
-  'states_id',
-  {
-    is_deferrable => 1,
-    on_delete     => "CASCADE",
-    on_update     => "CASCADE",
-    order_by      => 'name',
-    join_type     => 'left',
-  };
-
-=head2 country
-
-Type: belongs_to
-
-Related object: L<Interchange6::Schema::Result::Country>
-
-=cut
-
-belongs_to
-  country => "Interchange6::Schema::Result::Country",
-  'country_iso_code',
-  {
-    is_deferrable => 1,
-    on_delete     => "CASCADE",
-    on_update     => "CASCADE",
-    order_by      => 'name',
-    join_type     => 'left',
-  };
-
 =head1 METHODS
 
 =head2 calculate
@@ -265,21 +233,21 @@ sub calculate {
 
     # round & return
 
-    my $decimal_places = $self->decimal_places;
+    my $precision = $self->precision;
 
     unless ( $self->rounding ) {
 
-        return sprintf( "%.${decimal_places}f", $tax );
+        return sprintf( "%.${precision}f", $tax );
     }
     else {
 
-        $tax *= 10**$decimal_places;
+        $tax *= 10**$precision;
 
         if ( $self->rounding eq 'c' ) {
-            $tax = ceil($tax) / ( 10**$decimal_places );
+            $tax = ceil($tax) / ( 10**$precision );
         }
         elsif ( $self->rounding eq 'f' ) {
-            $tax = floor($tax) / ( 10**$decimal_places );
+            $tax = floor($tax) / ( 10**$precision );
         }
         else {
 
@@ -288,10 +256,66 @@ sub calculate {
                 "rounding value from database is invalid: " . $self->rounding );
         }
 
-        return sprintf( "%.${decimal_places}f", $tax );
+        return sprintf( "%.${precision}f", $tax );
     }
 }
 
+=head1 PRIMARY KEY
+
+=over 4
+
+=item * L</taxes_id>
+
+=back
+
+=cut
+
+__PACKAGE__->set_primary_key("taxes_id");
+
+=head1 RELATIONS
+
+=head2 State
+
+Type: belongs_to
+
+Related object: L<Interchange6::Schema::Result::State>
+
+=cut
+
+__PACKAGE__->belongs_to(
+    "State",
+    "Interchange6::Schema::Result::State",
+    'states_id',
+    {
+        is_deferrable => 1,
+        on_delete     => "CASCADE",
+        on_update     => "CASCADE",
+        order_by      => 'name',
+        join_type     => 'left',
+    }
+);
+
+=head2 Country
+
+Type: belongs_to
+
+Related object: L<Interchange6::Schema::Result::Country>
+
+=cut
+
+__PACKAGE__->belongs_to(
+    "Country",
+    "Interchange6::Schema::Result::Country",
+    'country_iso_code',
+    {
+        is_deferrable => 1,
+        on_delete     => "CASCADE",
+        on_update     => "CASCADE",
+        order_by      => 'name',
+        join_type     => 'left',
+    }
+);
+
 =head1 INHERITED METHODS
 
 =head2 new
@@ -303,11 +327,9 @@ We overload the new method to set default values on certain rows at create time.
 sub new {
     my ( $class, $attrs ) = @_;
 
-    my %attrs = %$attrs;
+    $attrs->{precision} = 2 unless defined $attrs->{precision};
 
-    $attrs->{decimal_places} = 2 unless defined $attrs->{decimal_places};
-
-    my $new = $class->next::method( \%attrs );
+    my $new = $class->next::method($attrs);
 
     return $new;
 }
@@ -342,6 +364,8 @@ sub sqlt_deploy_hook {
     );
 }
 
+=head1 INHERITED METHODS
+
 =head2 validate
 
 Validity checks that cannot be enforced using primary key, unique or other database methods using L<Interchange6::Schema::Component::Validation>. The validity checks enforce the following rules:
@@ -376,22 +400,6 @@ sub validate {
         }
     }
 
-    # rounding
-
-    if ( defined $self->rounding ) {
-
-        # set lower case
-
-        my $rounding = lc( $self->rounding );
-        $self->rounding($rounding);
-
-        unless ( $self->rounding =~ /^(c|f)$/ ) {
-            $self->rounding(undef);
-            $schema->throw_exception(
-                'value for rounding not c, f or undef: ' . $rounding );
-        }
-    }
-
     # check that valid_to is later than valid_from (if it is defined)
 
     $self->valid_from->truncate( to => 'day' );
@@ -406,22 +414,10 @@ sub validate {
         }
     }
 
-    # grab our resultset
-
-    $rset = $self->result_source->resultset;
-
-    if ( $self->in_storage ) {
-
-        # this is an update so we must exclude our existing record from
-        # the resultset before range overlap checks are performed
-
-        $rset = $rset->search( { taxes_id => { '!=', $self->taxes_id } } );
-    }
-
     # multiple entries for a single tax code do not overlap dates
 
     if ( defined $self->valid_to ) {
-        $rset = $rset->search(
+        $rset = $self->result_source->resultset->search(
             {
                 tax_name => $self->tax_name,
                 -or      => [
@@ -440,14 +436,13 @@ sub validate {
                 ],
             }
         );
-
         if ( $rset->count > 0 ) {
             $schema->throw_exception(
                 'tax overlaps existing date range: ' . $self->tax_name );
         }
     }
     else {
-        $rset = $rset->search(
+        $rset = $self->result_source->resultset->search(
             {
                 tax_name => $self->tax_name,
                 -or      => [
